@@ -1,9 +1,12 @@
+from wagtail.core import blocks
+
 from webspace.cms import constants
 from webspace.cms.blocks.common import EntryBlock, EmbedWithSizeBlock
 
 
 class EmbedEntry(EntryBlock):
     amp_scripts = ['iframe']
+    animation = blocks.BooleanBlock(required=False, help_text="Animation")
     embed = EmbedWithSizeBlock()
 
     def mock(self, size_media='m', *args, **kwargs):
